@@ -28,12 +28,8 @@
 #include <QHash>
 #include <QVector>
 #include <QThread>
-#include <QMetaObject>
 #include <QStandardPaths>
-#include <QDir>
-#include <QFile>
 
-#include <QDebug>
 
 #include <QtTest>
 
