@@ -27,13 +27,9 @@
 #include <QHash>
 #include <QVector>
 #include <QThread>
-#include <QMetaObject>
 #include <QStandardPaths>
-#include <QDir>
-#include <QFile>
 #include <QAbstractItemModelTester>
 
-#include <QDebug>
 
 #include <QtTest>
 
@@ -41,6 +37,12 @@ class AllTracksProxyModelTests: public QObject, public DatabaseTestData
 {
     Q_OBJECT
 
+public:
+
+    explicit AllTracksProxyModelTests(QObject *aParent = nullptr) : QObject(aParent)
+    {
+    }
+
 private Q_SLOTS:
 
     void initTestCase()
