@@ -27,10 +27,7 @@
 #include <QHash>
 #include <QVector>
 #include <QThread>
-#include <QMetaObject>
 #include <QStandardPaths>
-#include <QDir>
-#include <QFile>
 #include <QAbstractItemModelTester>
 
 #include <QDebug>
@@ -41,6 +38,12 @@ class DataModelTests: public QObject, public DatabaseTestData
 {
     Q_OBJECT
 
+public:
+
+    explicit DataModelTests(QObject *aParent = nullptr) : QObject(aParent)
+    {
+    }
+
 private Q_SLOTS:
 
     void initTestCase()
