@@ -19,7 +19,6 @@
 #define ABSTRACTFILELISTENER_H
 
 #include <QObject>
-#include <QVector>
 #include <QString>
 
 #include "datatypes.h"
@@ -28,7 +27,6 @@
 
 class AbstractFileListenerPrivate;
 class DatabaseInterface;
-class MusicAudioTrack;
 class AbstractFileListing;
 
 class AbstractFileListener : public QObject
@@ -49,6 +47,8 @@ public:
 
     AbstractFileListing* fileListing() const;
 
+    bool canHandleRootPaths() const;
+
 Q_SIGNALS:
 
     void databaseInterfaceChanged();
