@@ -21,14 +21,10 @@
 #include "../abstractfile/abstractfilelistener.h"
 
 #include <QObject>
-#include <QVector>
-#include <QString>
 
 #include <memory>
 
 class BalooListenerPrivate;
-class DatabaseInterface;
-class MusicAudioTrack;
 
 class BalooListener : public AbstractFileListener
 {
