@@ -37,21 +37,16 @@
 #include <KFileMetaData/Properties>
 #include <KFileMetaData/UserMetaData>
 
-#include <KLocalizedString>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
-#include <QDBusMessage>
 #include <QDBusServiceWatcher>
 
 #include <QThread>
 #include <QHash>
 #include <QFileInfo>
-#include <QDir>
 #include <QAtomicInt>
 #include <QScopedPointer>
-#include <QDebug>
-#include <QGuiApplication>
 
 #include <algorithm>
 #include <memory>
@@ -121,10 +116,55 @@ void LocalBalooFileListing::applicationAboutToQuit()
     d->mStopRequest = 1;
 }
 
+bool LocalBalooFileListing::canHandleRootPaths() const
+{
+    Baloo::IndexerConfig balooConfiguration;
+
+    auto balooIncludedFolders = balooConfiguration.includeFolders();
+    auto balooExcludedFolders = balooConfiguration.excludeFolders();
+
+    for (const auto &onePath : allRootPaths()) {
+        auto onePathInfo = QFileInfo{onePath};
+        auto onePathCanonicalPath = onePathInfo.canonicalFilePath();
+
+        auto includedPath = false;
+
+        for (const auto &balooIncludedPath : balooIncludedFolders) {
+            auto balooIncludedPathInfo = QFileInfo{balooIncludedPath};
+            auto balooIncludedCanonicalPath = balooIncludedPathInfo.canonicalFilePath();
+
+            if (onePathCanonicalPath.startsWith(balooIncludedCanonicalPath)) {
+                includedPath = true;
+                break;
+            }
+        }
+
+        for (const auto &balooExcludedPath : balooExcludedFolders) {
+            auto balooExcludedPathInfo = QFileInfo{balooExcludedPath};
+            auto balooExcludedCanonicalPath = balooExcludedPathInfo.canonicalFilePath();
+
+            if (onePathCanonicalPath.startsWith(balooExcludedCanonicalPath)) {
+                includedPath = false;
+                break;
+            }
+        }
+
+        if (!includedPath) {
+            return false;
+        }
+    }
+    return true;
+}
+
 void LocalBalooFileListing::newBalooFile(const QString &fileName)
 {
     qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::newBalooFile" << fileName;
 
+    if (!isActive()) {
+        qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::newBalooFile is inactive";
+        return;
+    }
+
     auto scanFileInfo = QFileInfo(fileName);
 
     if (!scanFileInfo.exists()) {
@@ -299,12 +339,24 @@ void LocalBalooFileListing::serviceUnregistered(const QString &serviceName)
 
 void LocalBalooFileListing::executeInit(QHash<QUrl, QDateTime> allFiles)
 {
+    if (!isActive()) {
+        qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::executeInit is inactive";
+        return;
+    }
+
+    qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::executeInit" << "with" << allFiles.size() << "files";
     AbstractFileListing::executeInit(std::move(allFiles));
 }
 
 void LocalBalooFileListing::triggerRefreshOfContent()
 {
     qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::triggerRefreshOfContent";
+
+    if (!isActive()) {
+        qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::triggerRefreshOfContent is inactive";
+        return;
+    }
+
     Q_EMIT indexingStarted();
 
     AbstractFileListing::triggerRefreshOfContent();
@@ -388,18 +440,16 @@ void LocalBalooFileListing::triggerRefreshOfContent()
     }
 }
 
+void LocalBalooFileListing::triggerStop()
+{
+    qCDebug(orgKdeElisaBaloo()) << "LocalBalooFileListing::triggerStop";
+    AbstractFileListing::triggerStop();
+}
+
 DataTypes::TrackDataType LocalBalooFileListing::scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
 {
-    DataTypes::TrackDataType trackData;
 
-    auto localFileName = scanFile.toLocalFile();
-
-    Baloo::File match(localFileName);
-
-    match.load();
-    fileScanner().scanProperties(match, trackData);
-    trackData[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
-    trackData[DataTypes::ResourceRole] = scanFile;
+    auto trackData = fileScanner().scanOneBalooFile(scanFile, scanFileInfo);
 
     if (!trackData.isValid()) {
         qCDebug(orgKdeElisaBaloo) << "LocalBalooFileListing::scanOneFile" << scanFile << "falling back to plain file metadata analysis";
@@ -407,7 +457,6 @@ DataTypes::TrackDataType LocalBalooFileListing::scanOneFile(const QUrl &scanFile
     }
 
     if (trackData.isValid()) {
-        trackData[DataTypes::HasEmbeddedCover] = checkEmbeddedCoverImage(localFileName);
         addCover(trackData);
     } else {
         qCDebug(orgKdeElisaBaloo) << "LocalBalooFileListing::scanOneFile" << scanFile << "invalid track";
@@ -416,5 +465,4 @@ DataTypes::TrackDataType LocalBalooFileListing::scanOneFile(const QUrl &scanFile
     return trackData;
 }
 
-
 #include "moc_localbaloofilelisting.cpp"
