@@ -40,6 +40,7 @@ class ManageMediaPlayerControl;
 class ManageHeaderBar;
 class QQmlApplicationEngine;
 class ElisaApplicationPrivate;
+class QSessionManager;
 
 class ELISALIB_EXPORT ElisaApplication : public QObject
 {
@@ -151,6 +152,8 @@ Q_SIGNALS:
 
     void showSystemTrayIconChanged();
 
+    void commitDataRequest(QSessionManager &manager);
+
 public Q_SLOTS:
 
     void appHelpActivated();
