@@ -21,8 +21,6 @@
 #include "../abstractfile/abstractfilelistener.h"
 
 #include <QObject>
-#include <QVector>
-#include <QString>
 
 class FileListenerPrivate;
 class LocalFileListing;
@@ -31,11 +29,6 @@ class FileListener : public AbstractFileListener
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString rootPath
-               READ rootPath
-               WRITE setRootPath
-               NOTIFY rootPathChanged)
-
 public:
     explicit FileListener(QObject *parent = nullptr);
 
@@ -43,16 +36,6 @@ public:
 
     const LocalFileListing& localFileIndexer() const;
 
-    QString rootPath() const;
-
-Q_SIGNALS:
-
-    void rootPathChanged();
-
-public Q_SLOTS:
-
-    void setRootPath(const QString &rootPath);
-
 private:
 
     std::unique_ptr<FileListenerPrivate> d;
