@@ -22,7 +22,6 @@
 
 #include "../abstractfile/abstractfilelisting.h"
 
-#include <QString>
 
 #include <memory>
 
@@ -47,6 +46,8 @@ private:
 
     void triggerStop() override;
 
+    DataTypes::TrackDataType scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo) override;
+
     std::unique_ptr<LocalFileListingPrivate> d;
 
 };
