@@ -38,36 +38,12 @@
 
 #endif
 
-#include <QLoggingCategory>
 #include <QFileInfo>
 #include <QLocale>
 #include <QDir>
 #include <QHash>
 #include <QMimeDatabase>
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
-
-static const QHash<KFileMetaData::Property::Property, DataTypes::ColumnsRoles> propertyTranslation = {
-    {KFileMetaData::Property::Artist, DataTypes::ColumnsRoles::ArtistRole},
-    {KFileMetaData::Property::AlbumArtist, DataTypes::ColumnsRoles::AlbumArtistRole},
-    {KFileMetaData::Property::Genre, DataTypes::ColumnsRoles::GenreRole},
-    {KFileMetaData::Property::Composer, DataTypes::ColumnsRoles::ComposerRole},
-    {KFileMetaData::Property::Lyricist, DataTypes::ColumnsRoles::LyricistRole},
-    {KFileMetaData::Property::Title, DataTypes::ColumnsRoles::TitleRole},
-    {KFileMetaData::Property::Album, DataTypes::ColumnsRoles::AlbumRole},
-    {KFileMetaData::Property::TrackNumber, DataTypes::ColumnsRoles::TrackNumberRole},
-    {KFileMetaData::Property::DiscNumber, DataTypes::ColumnsRoles::DiscNumberRole},
-    {KFileMetaData::Property::ReleaseYear, DataTypes::ColumnsRoles::YearRole},
-    {KFileMetaData::Property::Lyrics, DataTypes::ColumnsRoles::LyricsRole},
-    {KFileMetaData::Property::Comment, DataTypes::ColumnsRoles::CommentRole},
-    {KFileMetaData::Property::Rating, DataTypes::ColumnsRoles::RatingRole},
-    {KFileMetaData::Property::Channels, DataTypes::ColumnsRoles::ChannelsRole},
-    {KFileMetaData::Property::SampleRate, DataTypes::ColumnsRoles::SampleRateRole},
-    {KFileMetaData::Property::BitRate, DataTypes::ColumnsRoles::BitRateRole},
-    {KFileMetaData::Property::Duration, DataTypes::ColumnsRoles::DurationRole},
-};
-
-#endif
 class FileScannerPrivate
 {
 public:
@@ -80,15 +56,37 @@ public:
 #endif
 
     QMimeDatabase mMimeDb;
-};
 
-static const QStringList constSearchStrings = {
-    QStringLiteral("*[Cc]over*.jpg"),
-    QStringLiteral("*[Cc]over*.png"),
-    QStringLiteral("*[Ff]older*.jpg"),
-    QStringLiteral("*[Ff]older*.png"),
-    QStringLiteral("*[Ff]ront*.jpg"),
-    QStringLiteral("*[Ff]ront*.png")
+#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+    const QHash<KFileMetaData::Property::Property, DataTypes::ColumnsRoles> propertyTranslation = {
+        {KFileMetaData::Property::Artist, DataTypes::ColumnsRoles::ArtistRole},
+        {KFileMetaData::Property::AlbumArtist, DataTypes::ColumnsRoles::AlbumArtistRole},
+        {KFileMetaData::Property::Genre, DataTypes::ColumnsRoles::GenreRole},
+        {KFileMetaData::Property::Composer, DataTypes::ColumnsRoles::ComposerRole},
+        {KFileMetaData::Property::Lyricist, DataTypes::ColumnsRoles::LyricistRole},
+        {KFileMetaData::Property::Title, DataTypes::ColumnsRoles::TitleRole},
+        {KFileMetaData::Property::Album, DataTypes::ColumnsRoles::AlbumRole},
+        {KFileMetaData::Property::TrackNumber, DataTypes::ColumnsRoles::TrackNumberRole},
+        {KFileMetaData::Property::DiscNumber, DataTypes::ColumnsRoles::DiscNumberRole},
+        {KFileMetaData::Property::ReleaseYear, DataTypes::ColumnsRoles::YearRole},
+        {KFileMetaData::Property::Lyrics, DataTypes::ColumnsRoles::LyricsRole},
+        {KFileMetaData::Property::Comment, DataTypes::ColumnsRoles::CommentRole},
+        {KFileMetaData::Property::Rating, DataTypes::ColumnsRoles::RatingRole},
+        {KFileMetaData::Property::Channels, DataTypes::ColumnsRoles::ChannelsRole},
+        {KFileMetaData::Property::SampleRate, DataTypes::ColumnsRoles::SampleRateRole},
+        {KFileMetaData::Property::BitRate, DataTypes::ColumnsRoles::BitRateRole},
+        {KFileMetaData::Property::Duration, DataTypes::ColumnsRoles::DurationRole},
+    };
+#endif
+
+    const QStringList constSearchStrings = {
+        QStringLiteral("*[Cc]over*.jpg"),
+        QStringLiteral("*[Cc]over*.png"),
+        QStringLiteral("*[Ff]older*.jpg"),
+        QStringLiteral("*[Ff]older*.png"),
+        QStringLiteral("*[Ff]ront*.jpg"),
+        QStringLiteral("*[Ff]ront*.png")
+    };
 };
 
 FileScanner::FileScanner() : d(std::make_unique<FileScannerPrivate>())
@@ -103,18 +101,16 @@ bool FileScanner::shouldScanFile(const QString &scanFile)
 
 FileScanner::~FileScanner() = default;
 
-DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
+DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
 {
-
     DataTypes::TrackDataType newTrack;
 
     if (!scanFile.isLocalFile() && !scanFile.scheme().isEmpty()) {
         return newTrack;
     }
 
-    auto localFileName = scanFile.toLocalFile();
+    const auto &localFileName = scanFile.toLocalFile();
 
-    QFileInfo scanFileInfo(localFileName);
     newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
     newTrack[DataTypes::ResourceRole] = scanFile;
     newTrack[DataTypes::RatingRole] = 0;
@@ -125,9 +121,9 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
         return newTrack;
     }
 
-    QString mimetype = fileMimeType.name();
+    const auto &mimetype = fileMimeType.name();
 
-    QList<KFileMetaData::Extractor*> exList = d->mAllExtractors.fetchExtractors(mimetype);
+    const QList<KFileMetaData::Extractor*> &exList = d->mAllExtractors.fetchExtractors(mimetype);
 
     if (exList.isEmpty()) {
         return newTrack;
@@ -146,7 +142,7 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
     qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "using KFileMetaData" << newTrack;
 #else
     Q_UNUSED(scanFile)
-    Q_UNUSED(mimeDatabase)
+    Q_UNUSED(scanFileInfo)
 
     qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "no metadata provider" << newTrack;
 #endif
@@ -154,19 +150,41 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
     return newTrack;
 }
 
-void FileScanner::scanProperties(const Baloo::File &match, DataTypes::TrackDataType &trackData)
+DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
 {
+    if (!scanFile.isLocalFile()){
+        return {};
+    } else {
+        const QFileInfo scanFileInfo(scanFile.toLocalFile());
+        return FileScanner::scanOneFile(scanFile, scanFileInfo);
+    }
+}
+
+DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
+{
+    DataTypes::TrackDataType newTrack;
 #if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+    const auto &localFileName = scanFile.toLocalFile();
+
+    newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
+    newTrack[DataTypes::ResourceRole] = scanFile;
+    newTrack[DataTypes::RatingRole] = 0;
+
+    Baloo::File match(localFileName);
+
+    match.load();
+
     d->mAllProperties = match.properties();
-    scanProperties(match.path(), trackData);
+    scanProperties(match.path(), newTrack);
 
-    qCDebug(orgKdeElisaIndexer()) << "scanProperties" << match.path() << "using Baloo" << trackData;
+    qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "using Baloo" << newTrack;
 #else
-    Q_UNUSED(match)
-    Q_UNUSED(trackData)
+    Q_UNUSED(scanFile)
+    Q_UNUSED(scanFileInfo)
 
-    qCDebug(orgKdeElisaIndexer()) << "scanProperties" << "no metadata provider" << trackData;
+    qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "no baloo metadata provider" << newTrack;
 #endif
+    return newTrack;
 }
 
 void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackDataType &trackData)
@@ -180,16 +198,16 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
     auto rangeBegin = d->mAllProperties.constKeyValueBegin();
     QVariant value;
     while (rangeBegin != d->mAllProperties.constKeyValueEnd()) {
-        auto key = (*rangeBegin).first;
+        const auto key = (*rangeBegin).first;
 
-        auto rangeEnd = std::find_if(rangeBegin, d->mAllProperties.constKeyValueEnd(),
-                                     [key](const entry& e) { return e.first != key; });
+        const auto rangeEnd = std::find_if(rangeBegin, d->mAllProperties.constKeyValueEnd(),
+                                     [key](entry e) { return e.first != key; });
 
-        auto distance = std::distance(rangeBegin, rangeEnd);
+        const auto distance = std::distance(rangeBegin, rangeEnd);
         if (distance > 1) {
             QStringList list;
             list.reserve(static_cast<int>(distance));
-            std::for_each(rangeBegin, rangeEnd, [&list](const entry& s) { list.append(s.second.toString()); });
+            std::for_each(rangeBegin, rangeEnd, [&list](entry s) { list.append(s.second.toString()); });
             value = QLocale().createSeparatedList(list);
         } else {
             value = (*rangeBegin).second;
@@ -197,23 +215,29 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
                 value = QLocale().createSeparatedList(value.toStringList());
             }
         }
-        auto translatedKey = propertyTranslation.find(key);
+        const auto &translatedKey = d->propertyTranslation.find(key);
         if (translatedKey.value() == DataTypes::DurationRole) {
             trackData.insert(translatedKey.value(), QTime::fromMSecsSinceStartOfDay(int(1000 * (*rangeBegin).second.toDouble())));
-        } else if (translatedKey != propertyTranslation.end()) {
+        } else if (translatedKey != d->propertyTranslation.end()) {
             trackData.insert(translatedKey.value(), (*rangeBegin).second);
         }
         rangeBegin = rangeEnd;
     }
 
+    if (!trackData.isValid()) {
+        return;
+    }
+
+    trackData[DataTypes::HasEmbeddedCover] = checkEmbeddedCoverImage(localFileName);
+
 #if !defined Q_OS_ANDROID && !defined Q_OS_WIN
-    auto fileData = KFileMetaData::UserMetaData(localFileName);
-    QString comment = fileData.userComment();
+    const auto fileData = KFileMetaData::UserMetaData(localFileName);
+    const auto &comment = fileData.userComment();
     if (!comment.isEmpty()) {
         trackData[DataTypes::CommentRole] = comment;
     }
 
-    int rating = fileData.rating();
+    const auto rating = fileData.rating();
     if (rating >= 0) {
         trackData[DataTypes::RatingRole] = rating;
     }
@@ -227,18 +251,17 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
 
 QUrl FileScanner::searchForCoverFile(const QString &localFileName)
 {
-    QFileInfo trackFilePath(localFileName);
+    const QFileInfo trackFilePath(localFileName);
     QDir trackFileDir = trackFilePath.absoluteDir();
     trackFileDir.setFilter(QDir::Files);
-    trackFileDir.setNameFilters(constSearchStrings);
+    trackFileDir.setNameFilters(d->constSearchStrings);
     QFileInfoList coverFiles = trackFileDir.entryInfoList();
     if (coverFiles.isEmpty()) {
-        QString dirNamePattern = QLatin1String("*") + trackFileDir.dirName() + QLatin1String("*");
-        QString dirNameNoSpaces = dirNamePattern.remove(QLatin1Char(' '));
-        QStringList filters = {
+        const QString dirNamePattern = QLatin1String("*") + trackFileDir.dirName() + QLatin1String("*");
+        const QString dirNameNoSpaces = QLatin1String("*") + trackFileDir.dirName().remove(QLatin1Char(' ')) + QLatin1String("*");
+        const QStringList filters = {
             dirNamePattern + QStringLiteral(".jpg"),
             dirNamePattern + QStringLiteral(".png"),
-
             dirNameNoSpaces + QStringLiteral(".jpg"),
             dirNameNoSpaces + QStringLiteral(".png")
         };
@@ -254,7 +277,7 @@ QUrl FileScanner::searchForCoverFile(const QString &localFileName)
 bool FileScanner::checkEmbeddedCoverImage(const QString &localFileName)
 {
 #if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
-    auto imageData = d->mImageScanner.imageData(localFileName);
+    const auto &imageData = d->mImageScanner.imageData(localFileName);
 
     if (imageData.contains(KFileMetaData::EmbeddedImageData::FrontCover)) {
         if (!imageData[KFileMetaData::EmbeddedImageData::FrontCover].isEmpty()) {
