@@ -28,6 +28,8 @@
 #include <QReadWriteLock>
 #include <QThreadPool>
 
+class MediaPlayListProxyModel;
+
 class ELISALIB_EXPORT AbstractMediaProxyModel : public QSortFilterProxyModel
 {
 
@@ -47,6 +49,8 @@ class ELISALIB_EXPORT AbstractMediaProxyModel : public QSortFilterProxyModel
                READ sortedAscending
                NOTIFY sortedAscendingChanged)
 
+    Q_PROPERTY(MediaPlayListProxyModel* playList READ playList WRITE setPlayList NOTIFY playListChanged)
+
 public:
 
     explicit AbstractMediaProxyModel(QObject *parent = nullptr);
@@ -59,6 +63,8 @@ public:
 
     bool sortedAscending() const;
 
+    MediaPlayListProxyModel* playList() const;
+
 public Q_SLOTS:
 
     void setFilterText(const QString &filterText);
@@ -67,6 +73,8 @@ public Q_SLOTS:
 
     void sortModel(Qt::SortOrder order);
 
+    void setPlayList(MediaPlayListProxyModel* playList);
+
 Q_SIGNALS:
 
     void filterTextChanged(const QString &filterText);
@@ -75,10 +83,21 @@ Q_SIGNALS:
 
     void sortedAscendingChanged();
 
+    void playListChanged();
+
+    void entriesToEnqueue(const ElisaUtils::EntryDataList &newEntries,
+                          ElisaUtils::PlayListEntryType databaseIdType,
+                          ElisaUtils::PlayListEnqueueMode enqueueMode,
+                          ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
+
 protected:
 
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override = 0;
 
+    void disconnectPlayList();
+
+    void connectPlayList();
+
     QString mFilterText;
 
     int mFilterRating = 0;
@@ -89,6 +108,8 @@ protected:
 
     QThreadPool mThreadPool;
 
+    MediaPlayListProxyModel* mPlayList = nullptr;
+
 };
 
 #endif // ABSTRACTMEDIAPROXYMODEL_H
