@@ -19,18 +19,16 @@
 
 #include <QUrl>
 #include <QString>
-#include <QDebug>
 #include <QMimeDatabase>
 #include <KIOWidgets/KDirLister>
 
 FileBrowserModel::FileBrowserModel(QObject *parent) : KDirModel(parent)
 {
     QMimeDatabase db;
-    QList<QMimeType> mimeList = db.allMimeTypes();
-    QStringList mimeTypes;
-    mimeTypes << QStringLiteral("inode/directory");
-    foreach (const QMimeType &mime, mimeList) {
-        if (mime.name().startsWith(QStringLiteral("audio/"))) {
+    const QList<QMimeType> mimeList = db.allMimeTypes();
+    QStringList mimeTypes = { QStringLiteral("inode/directory") };
+    for (const QMimeType &mime : mimeList) {
+        if (mime.name().startsWith(QLatin1String("audio/"))) {
             mimeTypes << mime.name();
         }
     }
@@ -68,9 +66,9 @@ QHash<int, QByteArray> FileBrowserModel::roleNames() const
     auto roles = KDirModel::roleNames();
 
     roles[static_cast<int>(ColumnsRoles::NameRole)] = "name";
-    roles[static_cast<int>(ColumnsRoles::ContainerDataRole)] = "containerData";
+    roles[static_cast<int>(ColumnsRoles::FileUrlRole)] = "fileUrl";
     roles[static_cast<int>(ColumnsRoles::ImageUrlRole)] = "imageUrl";
-    roles[static_cast<int>(ColumnsRoles::DirectoryRole)] = "directory";
+    roles[static_cast<int>(ColumnsRoles::IsDirectoryRole)] = "isDirectory";
     roles[static_cast<int>(ColumnsRoles::IsPlayListRole)] = "isPlaylist";
 
     return roles;
@@ -92,10 +90,10 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
         result = item.name();
         break;
     }
-    case ColumnsRoles::ContainerDataRole:
+    case ColumnsRoles::FileUrlRole:
     {
         KFileItem item = itemForIndex(index);
-        result = item.url().toLocalFile();
+        result = item.url();
         break;
     }
     case ColumnsRoles::ImageUrlRole:
@@ -108,7 +106,7 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
         }
         break;
     }
-    case ColumnsRoles::DirectoryRole:
+    case ColumnsRoles::IsDirectoryRole:
     {
         KFileItem item = itemForIndex(index);
         result = item.isDir();
